==> packer_1.0.4+dfsg.orig.tar.gz: packer-1.0.4/command/version.go <==
package command

import (
	"bytes"
	"fmt"
)

// VersionCommand is a Command implementation prints the version.
type VersionCommand struct {
	Meta

	Revision          string
	Version           string
	VersionPrerelease string
	CheckFunc         VersionCheckFunc
}

// VersionCheckFunc is the callback called by the Version command to
// check if there is a new version of Packer.
type VersionCheckFunc func() (VersionCheckInfo, error)

// VersionCheckInfo is the return value for the VersionCheckFunc callback
// and tells the Version command information about the latest version
// of Packer.
type VersionCheckInfo struct {
	Outdated bool
	Latest   string
	Alerts   []string
}

func (c *VersionCommand) Help() string {
	return ""
}

func (c *VersionCommand) Run(args []string) int {
	c.Ui.Machine("version", c.Version)
	c.Ui.Machine("version-prelease", c.VersionPrerelease)
	c.Ui.Machine("version-commit", c.Revision)

	var versionString bytes.Buffer
	fmt.Fprintf(&versionString, "Packer v%s", c.Version)
	if c.VersionPrerelease != "" {
		fmt.Fprintf(&versionString, "-%s", c.VersionPrerelease)

		if c.Revision != "" {
			fmt.Fprintf(&versionString, " (%s)", c.Revision)
		}
	}

	c.Ui.Say(versionString.String())

	// If we have a version check function, then let's check for
	// the latest version as well.
	if c.CheckFunc != nil {

		// Check the latest version
		info, err := c.CheckFunc()
		if err != nil {
			c.Ui.Error(fmt.Sprintf(
				"\nError checking latest version: %s", err))
		}
		if info.Outdated {
			c.Ui.Say(fmt.Sprintf(
				"\nYour version of Packer is out of date! The latest version\n"+
					"is %s. You can update by downloading from www.packer.io",
				info.Latest))
		}
	}

	return 0
}

func (c *VersionCommand) Synopsis() string {
	return "Prints the Packer version"
}

==> packer-1.8.0.tar.gz: packer-1.8.0/command/version.go <==
package command

import (
	"fmt"

	"github.com/hashicorp/packer/version"
)

// VersionCommand is a Command implementation prints the version.
type VersionCommand struct {
	Meta

	CheckFunc VersionCheckFunc
}

// VersionCheckFunc is the callback called by the Version command to
// check if there is a new version of Packer.
type VersionCheckFunc func() (VersionCheckInfo, error)

// VersionCheckInfo is the return value for the VersionCheckFunc callback
// and tells the Version command information about the latest version
// of Packer.
type VersionCheckInfo struct {
	Outdated bool
	Latest   string
	Alerts   []string
}

func (c *VersionCommand) Help() string {
	return "Prints the Packer version, and checks for new release."
}

func (c *VersionCommand) Run(args []string) int {
	c.Ui.Machine("version", version.Version)
	c.Ui.Machine("version-prelease", version.VersionPrerelease)
	c.Ui.Machine("version-commit", version.GitCommit)

	c.Ui.Say(fmt.Sprintf("Packer v%s", version.FormattedVersion()))

	// If we have a version check function, then let's check for
	// the latest version as well.
	if c.CheckFunc != nil {

		// Check the latest version
		info, err := c.CheckFunc()
		if err != nil {
			c.Ui.Error(fmt.Sprintf(
				"\nError checking latest version: %s", err))
		}
		if info.Outdated {
			c.Ui.Say(fmt.Sprintf(
				"\nYour version of Packer is out of date! The latest version\n"+
					"is %s. You can update by downloading from www.packer.io/downloads",
				info.Latest))
		}
	}

	return 0
}

func (c *VersionCommand) Synopsis() string {
	return "Prints the Packer version"
}
